abacusai.inferred_feature_mappings — AbacusAI documentation

# abacusai.inferred_feature_mappings

## Classes

`InferredFeatureMappings` | A description of the data use for a feature

## Module Contents

class abacusai.inferred_feature_mappings.InferredFeatureMappings(client, error=None, featureMappings={})

  Bases: `abacusai.return_class.AbstractApiClass`

  A description of the data use for a feature

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - error (str) – Error message if there was an error inferring the feature mappings

    - featureMappings (FeatureMapping) – The inferred feature mappings

  error
  feature_mappings
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict